.. _delu:

delu
====

.. currentmodule:: delu

.. automodule:: delu

.. rubric:: Tensor operations

.. autosummary::
   :nosignatures:
   :toctree: api

   to
   cat
   iter_batches

.. rubric:: Monitoring

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   ProgressTracker
   Timer

.. rubric:: Submodules

See the sidebar on the left.

----

.. rubric:: Deprecated items

.. raw:: html

   <details>
   <summary>Show</summary>

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class.rst

   Stream

.. autosummary::
   :nosignatures:
   :toctree: api

   collate
   concat
   improve_reproducibility

.. autosummary::
   :nosignatures:
   :toctree: api
   :template: class_just_autoclass.rst

   evaluation

.. raw:: html

   </details>
